"use strict";
var log_1 = require("../log");
var client = require('socket.io-client');
var SocketSubscriber = (function () {
    function SocketSubscriber(options) {
        this.options = options;
        if (typeof options.socket === 'object' && options.socket.hasOwnProperty('host')) {
            this.io = client(options.socket.host, options.socket.opts);
            this.io.on('connect', function () {
                log_1.Log.success('Connected to socket server!');
            });
            this.io.on('connect_error', function (e) {
                log_1.Log.error('Socket Error: ' + e + '\n');
            });
            this.io.on('connect_timeout', function () {
                log_1.Log.error('Socket Timeout...\n');
            });
            this.io.on('error', function (e) {
                log_1.Log.error("Socket Error: " + e + "\n");
            });
        }
    }
    Object.defineProperty(SocketSubscriber.prototype, "isSubscribed", {
        get: function () {
            return typeof this.io !== 'undefined';
        },
        enumerable: true,
        configurable: true
    });
    SocketSubscriber.prototype.subscribe = function (callback) {
        var _this = this;
        if (this.isSubscribed) {
            this.io.on('event', function (_a) {
                var channel = _a.channel, message = _a.message;
                if (_this.options.devMode) {
                    log_1.Log.info("Channel: " + channel);
                    log_1.Log.info("Event: " + message.event);
                }
                callback(channel, message);
            });
            log_1.Log.success('Listening for socket events...');
        }
        return Promise.resolve();
    };
    return SocketSubscriber;
}());
exports.SocketSubscriber = SocketSubscriber;
